@@ -25,4 +25,4 @@ def f(x):
     return simple.piece_of_cake()
 
 def g(x):
-    return f(x)
+    return g(f(x))
