@@ -13,7 +13,7 @@ class Test4:
         g4(self)
 
 class Tset4:
-    def __init__(self):
+    def ftset4(self):
         f4(self)
     def parse(self):
         g4(self)
